summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPaul Buetow <paul@buetow.org>2026-02-17 19:00:34 +0200
committerPaul Buetow <paul@buetow.org>2026-02-17 19:00:34 +0200
commit2c08decf4569f9ed55714120ca2a2cb6521d292e (patch)
tree09df5f29991c92a944dc9f509f8d0f29125b4118
parent362e3e8112ad36d21bd570aa062e9f7185a8b9e9 (diff)
Bump version to 0.11.0, change separator color to red0.11.0
Co-Authored-By: Claude Opus 4.6 <noreply@anthropic.com>
-rw-r--r--internal/display/display.go4
-rw-r--r--internal/display/display_test.go14
-rw-r--r--internal/version/version.go2
3 files changed, 10 insertions, 10 deletions
diff --git a/internal/version/version.go b/internal/version/version.go
index bc3d485..2ba0f52 100644
--- a/internal/version/version.go
+++ b/internal/version/version.go
@@ -1,4 +1,4 @@
package version
// Version is the application version (set at build time or here for development).
-const Version = "0.10.1"
+const Version = "0.11.0"
diff --git a/internal/display/display.go b/internal/display/display.go
index 623bde3..749c26c 100644
--- a/internal/display/display.go
+++ b/internal/display/display.go
@@ -324,9 +324,9 @@ func drawBars(renderer *sdl.Renderer, snap map[string]*stats.HostStats, cfg *con
separators = append(separators, sepRect{sx, sy, sh})
}
}
// Draw 1px yellow vertical separators on top of all bars
for _, sep := range separators {
- renderer.SetDrawColor(constants.Yellow.R, constants.Yellow.G, constants.Yellow.B, 255)
+ renderer.SetDrawColor(constants.Red.R, constants.Red.G, constants.Red.B, 255)
renderer.FillRect(&sdl.Rect{X: sep.x, Y: sep.y, W: 1, H: sep.h})
}
}
@@ -324,9 +324,9 @@ func drawBars(renderer *sdl.Renderer, snap map[string]*stats.HostStats, cfg *con
}
}
- // Draw 1px yellow vertical separators on top of all bars
+ // Draw 1px red vertical separators on top of all bars (same color as CPU steal)
for _, sep := range separators {
diff --git a/internal/display/display_test.go b/internal/display/display_test.go
index 786291f..332fe32 100644
--- a/internal/display/display_test.go
+++ b/internal/display/display_test.go
@@ -1317,7 +1317,7 @@ func TestSeparator_TwoHosts_Enabled(t *testing.T) {
drawFrame(renderer, src, cfg, state)
// 2 bars at 200px → each 100px. Separator at x=100 (start of second host's bars)
- assertPixelColor(t, surface, 100, 50, constants.Yellow, 3, "separator yellow at x=100")
+ assertPixelColor(t, surface, 100, 50, constants.Red, 3, "separator red at x=100")
}
func TestSeparator_TwoHosts_Disabled(t *testing.T) {
@@ -1353,7 +1353,7 @@ func TestSeparator_TwoHosts_Disabled(t *testing.T) {
drawFrame(renderer, src, cfg, state)
// At x=100, should be blue (second host's system bar), NOT yellow separator
assertPixelColor(t, surface, 100, 50, constants.Blue, 3, "no separator, should be blue")
}
@@ -1386,14 +1386,14 @@ func TestSeparator_SingleHost(t *testing.T) {
drawFrame(renderer, src, cfg, state)
// No separator at the edges — just verify no yellow at x=0 or x=99
r, g, b := getPixelColor(surface, 0, 50)
- if r == constants.Yellow.R && g == constants.Yellow.G && b == constants.Yellow.B {
- t.Errorf("unexpected yellow separator at x=0 with single host")
+ if r == constants.Red.R && g == constants.Red.G && b == constants.Red.B {
+ t.Errorf("unexpected red separator at x=0 with single host")
}
r, g, b = getPixelColor(surface, 99, 50)
- if r == constants.Yellow.R && g == constants.Yellow.G && b == constants.Yellow.B {
- t.Errorf("unexpected yellow separator at x=99 with single host")
+ if r == constants.Red.R && g == constants.Red.G && b == constants.Red.B {
+ t.Errorf("unexpected red separator at x=99 with single host")
}
}
@@ -1353,7 +1353,7 @@ func TestSeparator_TwoHosts_Disabled(t *testing.T) {
drawFrame(renderer, src, cfg, state)
- // At x=100, should be blue (second host's system bar), NOT yellow separator
+ // At x=100, should be blue (second host's system bar), NOT red separator
assertPixelColor(t, surface, 100, 50, constants.Blue, 3, "no separator, should be blue")
}
@@ -1386,14 +1386,14 @@ func TestSeparator_SingleHost(t *testing.T) {
drawFrame(renderer, src, cfg, state)
- // No separator at the edges — just verify no yellow at x=0 or x=99
+ // No separator at the edges — just verify no red separator at x=0 or x=99
r, g, b := getPixelColor(surface, 0, 50)